@@ -1,13 +1,12 @@
 from django.conf import settings
 from django.core.cache.backends.memcached import MemcachedCache, PyLibMCCache
 
+from cascache.exceptions import NoneValueError
+
+
 MAX_RETRIES = settings.get('CAS_CACHE_MAX_RETRIES', 10)
 
 
-class NoneValueError(Exception):
-    pass
-
-
 class CASMixin(object):
     def cas(self, key, update_func, timeout=0, version=None):
         key = self.make_key(key, version=version)
